#include <p33fj256gp710.h>
#include "PCM_X2.h"

// I/O definitions
#define SYNC    _LATG0  // output 
#define SDO     _RF8    // SPI1 SDO


#define _FAR __attribute__(( far))


//-------------------------------------------INTERRUPT ROUTINES----------------------------------------
void _ISRFAST _T3Interrupt( void)
{
   
    _T3IF = 0; // clear the interrupt flag

} // T3Interrupt

void _ISRFAST _OC1Interrupt( void)
{
   
    _OC1IF = 0; // clear the interrupt flag

} // OC1Interrupt

void _ISRFAST _CNInterrupt( void)
{

  	TMR3 = (CLOCK_PERIOD/2)-1;  //force transition by overwriting current value of TMR3

    _CNIF = 0; // clear the interrupt flag

} // IC1Interrupt


//-------------------------------------------END OF INTERRUPT ROUTINES----------------------------------------
//------------------------------------------------------------------------------------------------------------
//---------------------------------------START OF INITIALIZATION ROUTINES-------------------------------------
void initSys( void)
{
	//Set Oscillator Configuration for 40MIPS
	OSCCON = 0x0300;			//
	CLKDIV = 0x0000;			//
	PLLFBD = 0x0026;			//
	
    // set the priority levels
	_T3IP  = 4; 				// this is the default value anyway
	_OC1IP = 4;		
    _OC2IP = 4;		
	_OC3IP = 4;
    _OC4IP = 4;

    //init TMR3 to provide timebase for data clock
	T3CON = 0x8000;				// enabled, prescaler 1:1, internal clock 	
	PR3 = CLOCK_PERIOD-1;

	// set initial duty cycles for OC module
	OC1R  = (CLOCK_PERIOD/2);
	OC1RS = (CLOCK_PERIOD/2);
	
	//activate CN module
	CNEN2 = 0x0001;
	TMR3 = 0;

	//setup OC Module
	OC1CON = 0x000D;			

	// init Interrupts, clear the flag
	_OC1IF = 0;	_OC1IE = 0;		
    _CNIF  = 0;	_CNIE  = 1;	
	_T3IF  = 0; _T3IE  = 0;		
    	
	// init the processor priority level
	_IPL = 0;					// this is the default value anyway
    
    // init PORTS
    _TRISG0 = 0;            	// output the clock pin
	//_TRISD7 = 1;				//CN16 input


} // initSys

//---------------------------------------END OF INITIALIZATION ROUTINES---------------------------------------
//------------------------------------------------------------------------------------------------------------
//-------------------------------------------------- MAIN ----------------------------------------------------
int main()
{

    // initializations
    initSys();    	// initialize system

	while(1)
	{
		//main loop
		//using change notification
	}

	return 0;
	
} // main
//------------------------------------------------------------------------------------------------------------
